% Summary1

% 1a. read and do cumulative plot of the 18 sources load timeseries
% 1b. " " but NOT cumulative (linear and log)
% 2. re-generate one pager plots for all 18 (so they are in one place)
% 3. do table comparing results to 2000-04, 2007-10, and 2013-15 periods
% 4. save conc/flow/load results in mat, xlsx formats

% basic initial setup
wipe;
modprelims;

% retrieve inputs
ingrps = { 'Config'; }; inputsdiary;

%% read data from its various original locations and sort by source size
ddn = datenum(2001,1,1):datenum(2017,12,31);
allTNloads = nan*ones(18,length(ddn));
nam = cell(18,1);
titl = cell(18,1);
for i = 1:18
    load([src{i}{2} src{i}{1}],'TNload','TNconc','Qflow');
    allTNloads(i,:) = TNload;
    allTNconcs(i,:) = TNconc;
    allQflows(i,:) = Qflow;
    titl{i} = src{i}{3};
    nam{i} = src{i}{1};
end

% sort based on long term mean TN load
mns = mean(allTNloads')';
[mns,ind] = sort(mns,'descend');
nam = nam(ind);
titl = titl(ind);
allTNloads = allTNloads(ind,:);
allTNconcs = allTNconcs(ind,:);
allQflows = allQflows(ind,:);
clear ind TNload TNconc Qflow;

%% 1a. cumulative plot (loads)
figland('on');
axes;
hold;
set(gca,'ylim',[0 1.2e8/1000]);
loads = cumsum([zeros(size(ddn)); allTNloads;]);
clr = distinguishable_colors(18);
for i = 1:18
    fprintf('plotting source %d: %s\n',i,nam{i});
    lh(i) = fill([ddn fliplr(ddn)],[0.001*loads(i,:) ...
        fliplr(0.001*loads(i+1,:))],...
        clr(i,:),'linestyle','none');
    % plot(ddn,loads(i+1,:),'k');
end
datetick;
set(gca,'xlim',[ddn(1) ddn(end)]);
legend(lh,titl);
ylabel('TN Load [1000 lb yr^{-1}]');
grid on;
set(gcf,'PaperOrientation','Portrait');
print -dpng plt/cumulative;
delete(gcf);


%% 2. one-pagers (so have them all in one place)
% also, this version of makeplot differs from the others:
%   uses black instead of blue, for data points
%   uses 1000 lb yr-1 (isntead of lb yr-1)
for i = 1:18
    makeplot(titl{i},ddn,allTNloads(i,:),allTNconcs(i,:),allQflows(i,:));
end

%% 3. table comparing to SBNIW
if exist('dat/Table.xlsx', 'file')==2
  delete('dat/Table.xlsx');
end
% compute my results for the periods tallied by SNBIW
whr = find(ddn>=datenum(2000,1,1) & ddn<=datenum(2004,12,31));
my_pd1 = round(0.001*mean(allTNloads(:,whr)')');
my_pd1 = [my_pd1; sum(my_pd1);];
whr = find(ddn>=datenum(2007,1,1) & ddn<=datenum(2010,12,31));
my_pd2 = round(0.001*mean(allTNloads(:,whr)')');
my_pd2 = [my_pd2; sum(my_pd2);];
whr = find(ddn>=datenum(2013,1,1) & ddn<=datenum(2015,12,31));
my_pd3 = round(0.001*mean(allTNloads(:,whr)')');
my_pd3 = [my_pd3; sum(my_pd3);];
clear whr;

% read in SNBIW tallies & order same way as mine
[~,~,raw] = xlsread(snbiwfile);
snbiw_pd1 = raw(5:end,3);
snbiw_pd2 = raw(5:end,5);
snbiw_pd3 = raw(5:end,7);
xlsnam = raw(5:end,1);
ind = nan*ones(size(xlsnam));
for i = 1:length(nam)
    for j = 1:length(xlsnam)
        if isequal(nam{i},xlsnam{j})
            ind(i) = j;
        end
    end
end
snbiw_pd1 = round(cellfun(@abs,snbiw_pd1(ind)));
snbiw_pd1 = [snbiw_pd1; sum(snbiw_pd1);];
snbiw_pd2 = round(cellfun(@abs,snbiw_pd2(ind)));
snbiw_pd2 = [snbiw_pd2; sum(snbiw_pd2);];
snbiw_pd3 = round(cellfun(@abs,snbiw_pd3(ind)));
snbiw_pd3 = [snbiw_pd3; sum(snbiw_pd3);];
titl{length(titl)+1} = 'Total all sources';
clear ind raw xlsnam i j;

% make table including percent difference
delta_pd1 = round(100*(my_pd1-snbiw_pd1)./snbiw_pd1);
delta_pd2 = round(100*(my_pd2-snbiw_pd2)./snbiw_pd2);
delta_pd3 = round(100*(my_pd3-snbiw_pd3)./snbiw_pd3);

abs1 = abs(delta_pd1);
T1 = table(snbiw_pd1,my_pd1,delta_pd1,abs1,...
    'VariableNames',{'SNBIW','New','PctDiff','AbsPctDiff'});
abs2 = abs(delta_pd2);
T2 = table(snbiw_pd2,my_pd2,delta_pd2,abs2,...
    'VariableNames',{'SNBIW','New','PctDiff','AbsPctDiff'});
abs3 = abs(delta_pd3);
T3 = table(snbiw_pd3,my_pd3,delta_pd3,abs3,...
    'VariableNames',{'SNBIW','New','PctDiff','AbsPctDiff'});

T = table(titl,T1,T2,T3,...
  'VariableNames',{'Source','Yr2000to2004','Yr2007to2010','Yr2013to2015'});

Source = table(titl,'VariableNames',{'Source'});

writetable(T1,'dat/ComparisonTable.xlsx','Sheet',1,'Range','B2:E21');
writetable(table(titl,'VariableNames',{'Yr2000to04'}),...
    'dat/ComparisonTable.xlsx','Sheet',1,'Range','C1:C1');
writetable(T2,'dat/ComparisonTable.xlsx','Sheet',1,'Range','G2:J21');
writetable(table(titl,'VariableNames',{'Yr2007to10'}),...
    'dat/ComparisonTable.xlsx','Sheet',1,'Range','H1:H1');
writetable(T3,'dat/ComparisonTable.xlsx','Sheet',1,'Range','L2:O21');
writetable(table(titl,'VariableNames',{'Yr2013to15'}),...
    'dat/ComparisonTable.xlsx','Sheet',1,'Range','M1:M1');
writetable(Source,'dat/ComparisonTable.xlsx','Sheet',1,'Range','A2:A21');
% (must manually compute mean of abs pct diffs)

%% 4. save data to single mat file, xlsx file, csv file
SourceNames = titl;
SourceNames{end} = 'TotalAllSourcesSummed';
dn = ddn;
readme = {  'dn = matlab datenum       ';... 
            'TN load [1000 lb yr-1]    ';...
            'TN conc [mg L-1]          ';...
            'Q (flow) [MGD]            ';};
allTNloads = 0.001*allTNloads;
allTNloads = [allTNloads; sum(allTNloads);];
allTNconcs = [allTNconcs; sum(allTNconcs);];
allQflows = [allQflows; sum(allQflows);];
save dat/Daily2001to2017TNloadTNconcQflow18NBsources ...
    readme SourceNames dn allTNloads allTNconcs allQflows;

% save to xlsx
if exist('dat/Daily2001to2017TNloadTNconcQflow18NBsources.xlsx','file')==2
  delete('dat/Daily2001to2017TNloadTNconcQflow18NBsources.xlsx');
end
readme = table(readme(2:4));
writetable(readme,...
    'dat/Daily2001to2017TNloadTNconcQflow18NBsources.xlsx',...
    'Sheet','readme','WriteVariableNames',false);
writetable(table(datestr(dn'),'VariableNames',{'Date'}),...
    'dat/Daily2001to2017TNloadTNconcQflow18NBsources.xlsx',...
    'Sheet','TN load');
writetable(table(allTNloads'),...
    'dat/Daily2001to2017TNloadTNconcQflow18NBsources.xlsx',...
    'Sheet','TN load','Range','B2:T6210','WriteVariableNames',false);
writetable(table(SourceNames'),...
    'dat/Daily2001to2017TNloadTNconcQflow18NBsources.xlsx',...
    'Sheet','TN load','Range','B1:T1','WriteVariableNames',false);
writetable(table(datestr(dn'),'VariableNames',{'Date'}),...
    'dat/Daily2001to2017TNloadTNconcQflow18NBsources.xlsx',...
    'Sheet','TN conc');
writetable(table(allTNconcs'),...
    'dat/Daily2001to2017TNloadTNconcQflow18NBsources.xlsx',...
    'Sheet','TN conc','Range','B2:T6210','WriteVariableNames',false);
writetable(table(SourceNames'),...
    'dat/Daily2001to2017TNloadTNconcQflow18NBsources.xlsx',...
    'Sheet','TN conc','Range','B1:T1','WriteVariableNames',false);
writetable(table(datestr(dn'),'VariableNames',{'Date'}),...
    'dat/Daily2001to2017TNloadTNconcQflow18NBsources.xlsx',...
    'Sheet','Q (flow)');
writetable(table(allQflows'),...
    'dat/Daily2001to2017TNloadTNconcQflow18NBsources.xlsx',...
    'Sheet','Q (flow)','Range','B2:T6210','WriteVariableNames',false);
writetable(table(SourceNames'),...
    'dat/Daily2001to2017TNloadTNconcQflow18NBsources.xlsx',...
    'Sheet','Q (flow)','Range','B1:T1','WriteVariableNames',false);
RemoveSheet123('dat/Daily2001to2017TNloadTNconcQflow18NBsources.xlsx');

% end of module
diary off;