% UngaugedLoad 29-May-2019 

% Compute the runoff allocated to the ungauged riparian area.
% Compute load as product of it and constant conc (from Fulweiler & Nixon).


% basic initial setup
wipe;
modprelims;

% retrieve inputs
ingrps = { 'Config'; }; inputsdiary;

%% rivers
% get unscaled data
rivs = load([q.indir q.infil]);
% trim to keep only 2001-2017
whr = find(rivs.dn>=datenum(2001,1,1) & rivs.dn<=datenum(2017,12,31));
rivs.m3persec = rivs.m3persec(:,whr);
rivs.dn = rivs.dn(whr);

% pull the desired 6 rivers, scale each up, and sum them to create Q6
Q6 = zeros(size(rivs.m3persec(1,:))); 
for iriv = 1:length(nams)
    [~,ind] = ismember(rivs.rivnam,q.rivnam{iriv});
    ind = find(ind);
    Q6 = Q6 + rivs.m3persec(ind,:)*q.ungaugedfac(iriv);
end

Qflow = (1/0.043813)* Q6*Ar/A6; % (1/0.043813) converts to MGD from m3/s 
TNconc = Cr*ones(size(Qflow)); % mg/L
TNload = 3043*TNconc.*Qflow; % 3043 converts to lb/y from MGD-mg/L
ddn = datenum(2001,1,1):datenum(2017,12,31);

readme = 'ddn = daily datenum; TNload [lb/y]; TNconc [mg/l]; Qflow [MGD]';

save dat/Ungauged readme TNload TNconc Qflow ddn;

makeplot('Ungauged',ddn,TNload,TNconc,Qflow);


% end of module
diary off;