% FRLoadCalc 02-Jun-2019 

% remove outliers, compute load, save matfile & plot in standard format 
%   used by all 18 sources.

% methods notes:
%   Raw data obtained directly from Fall River WWTF.
%   Daily flow.
%   TKN, NO3, and NO2 are monthly during winter and weekly or bimonthly
%       during summer.
%   TN calculated as TKN + NO3 + NO2.

% basic initial setup
wipe;
modprelims;

% retrieve inputs
ingrps = { 'Config'; }; inputsdiary;

load(infil);

newrdme = 'ddn = daily datenum; TNload [lb/y]; TNconc [mg/l]; Qflow [MGD]';
readme = newrdme;

% address an outlier in NO3
NO3 = filloutliers(NO3,'nearest','thresholdfactor',20);
% address an outlier in NO2
NO2 = filloutliers(NO2,'nearest','thresholdfactor',25);

% interp fill TKN, NO3, NO2
NO3 = interp1(ddn(~isnan(NO3)),NO3(~isnan(NO3)),ddn);
NO3 = fillmissing(NO3,'nearest');
NO2 = interp1(ddn(~isnan(NO2)),NO2(~isnan(NO2)),ddn);
NO2 = fillmissing(NO2,'nearest');
TKN = interp1(ddn(~isnan(TKN)),TKN(~isnan(TKN)),ddn);
TKN = fillmissing(TKN,'nearest');

% interp fill Q
Qflow = interp1(ddn(~isnan(Qflow)),Qflow(~isnan(Qflow)),ddn);


TNconc = TKN+NO3+NO2; % mg/L
TNload = 3043*TNconc.*Qflow;

save dat/FallRiver readme TNload TNconc Qflow ddn;

makeplot('FallRiver',ddn,TNload,TNconc,Qflow);

% end of module
diary off;