% FPBP1 04-Apr-2019 

% This is stage 1. It does the calcs, saves results in a single mat file
%   (both WWTFs), and creates plots. 

% Stage 2 is called FPBP2 and all it does is to translate outputs from this
%       module in to mat files and plots that are in the "standard" format
%       of all 18 sources, so they can be merged.

% basic initial setup
wipe;
modprelims;

% retrieve inputs
ingrps = { 'Config'; }; inputsdiary;

pltdir = ['C:\dc\consult\2018nbep\analysis\NutrientLoads\WWTFs\'...
    'FieldsBucklin\FPBP1\plt\'];

%% new time axis
dn = datenum(2001,1,1):datenum(2017,12,31);

str = sprintf('save dat/WWTFsLdTN ');
for iw = 1:length(wwtfs)
    dat = wwtfs{iw};
    fprintf('working on %s (%d of %d)\n',dat.nam,iw,length(wwtfs));
    % get data from spreadsheet
    [~,~,raw] = xlsread([dat.in.dir dat.in.fil]);    
    % strip off col headers
    raw = raw(3:end,:);
    % extract numeric values from cell
    % CONC 
    tn = cell2mat(raw(:,8)); 
    tkn = cell2mat(raw(:,7));
    nh4 = cell2mat(raw(:,6));
    no32 = cell2mat(raw(:,5));
    no3 = cell2mat(raw(:,4));
    no2 = cell2mat(raw(:,3));
    dat.dn.raw = cellfun(@datenum,raw(:,1));

    if iw ==1 % Fields
        % replace missing tn with tkn+no2+no3
        whr = find(isnan(tn));
        tn(whr) = tkn(whr)+no3(whr)+no2(whr);
        % replace few remaining missing tn with regression against no2+nh4
        mdli = nh4+no2;
        mdlo = tn;
        mdlo(isnan(mdlo)) = estbyregr(mdli,mdlo,'linear',mdli(isnan(mdlo)),...
        pltdir,[dat.nam '-TNfromSumNO2NH4']);
        tn = mdlo;
        clear mdli mdlo whr;
    else % Bucklin
        % replace missing tn with tkn+no32
        whr = find(isnan(tn));
        tn(whr) = tkn(whr)+no32(whr);
        % replace few remaining missing tn with regression against nh4
        mdli = nh4;
        mdlo = tn;
        mdlo(isnan(mdlo)) = estbyregr(mdli,mdlo,'linear',mdli(isnan(mdlo)),...
        pltdir,[dat.nam '-TNfromNH4']);
        tn = mdlo;
        clear mdli mdlo whr;
        % replace last indiv remaining missing tn with regression vs no2
        mdli = no2;
        mdlo = tn;
        mdlo(isnan(mdlo)) = estbyregr(mdli,mdlo,'linear',mdli(isnan(mdlo)),...
        pltdir,[dat.nam '-TNfromNO2']);
        tn = mdlo;
        clear mdli mdlo whr;
    end
    % fill outliers
    % tn = filloutliers(tn,'nearest');
    dat.conc.raw = tn; % ppm
    clear tn tkn no2 no3 no32 nh4;
    dat.conc.raw = dat.conc.raw * 1000; % ug/L or ppb
    dat.conc.units = 'ug L-1';
    dat.dn.daily = dn;  
    % interp-fill the conc (still leaves early years missing)
    dat.conc.interp = interp1(dat.dn.raw,dat.conc.raw,dn);

    % FLOW
    dat.flow.raw = cell2mat(raw(:,2)); % mgd
    dat.flow.raw = dat.flow.raw * 0.0438; % m3/s
    dat.flow.units = 'm3 s-1';
    % fill outliers
    % dat.flow.interp = filloutliers(dat.flow.interp,'nearest');
    % interp-fill the flow (still leaves early years missing)
    dat.flow.interp = interp1(dat.dn.raw,dat.flow.raw,dn);

    clear raw;
    
    % compute load (raw; early years missing)
    dat.load.raw = dat.flow.raw.* dat.conc.raw; % ug-N L-1 m3 s-1
    % conversion factor: 69.6 lb N yr-1 per ug-N L-1 m3 s-1
    dat.load.raw = dat.load.raw * 69.6; % lb yr-1
    dat.load.units = 'lb yr-1';

    % interp-fill the load (product of conc and flow)
    ind = find(~isnan(dat.load.raw));
    dat.load.interp = interp1(dat.dn.raw(ind),dat.load.raw(ind),dn);
    clear ind;
    % last bit of 2017
    dat.load.interp(isnan(dat.load.interp) & ...
        dat.dn.daily>datenum(2017,12,1)) = dat.load.raw(end);

    % fill the empty early years 2001-2003
    % ".interp" means full length, filled by interp (but empty 2001-2003)
    % ".daily" means " " and 2001-2003 filled using monthly data from RIDEM
    % get data from RIDEM (daily res but interped from monthly values)
    ridem = load([wwtfs{iw}.ridem.dir wwtfs{iw}.ridem.fil]);
    dat.conc.daily = dat.conc.interp;
    dat.conc.daily(isnan(dat.conc.daily)) = ...
        1000*ridem.TNconc(isnan(dat.conc.daily));
    dat.flow.daily = dat.flow.interp;
    dat.flow.daily(isnan(dat.flow.daily)) = ...
        0.0438*ridem.Qflow(isnan(dat.flow.daily));
    dat.load.daily = dat.load.interp;
    dat.load.daily(isnan(dat.load.daily)) = ...
        ridem.TNload(isnan(dat.load.daily));
    
    %% make linear plot
    figland('on');
    % top frame flow
    subplot(3,1,1);
    plot(dat.dn.raw,dat.flow.raw,'ro');
    hold;
    plot(dat.dn.daily,dat.flow.daily,'b.');    
    grid on;
    set(gca,'xlim',[min(dn) max(dn)]);
    datetick('keeplimits');
    ylabel('flow m3 s-1');
    title(dat.nam);
    % middle frame conc
    subplot(3,1,2);
    plot(dat.dn.raw,dat.conc.raw,'ro');
    hold;
    plot(dat.dn.daily,dat.conc.daily,'k.');
    grid on;
    set(gca,'xlim',[min(dn) max(dn)]);
    datetick('keeplimits');
    ylabel('conc ug/L');
    % bottom frame load
    subplot(3,1,3);
    % plot(dat.dn.raw,dat.load.raw,'ro');
    plot(dat.dn.daily,dat.load.daily,'k.');
    hold;
    grid on;
    set(gca,'xlim',[min(dn) max(dn)]);
    datetick('keeplimits');
    ylabel('load lb/yr');
    set(gcf,'paperorientation','portrait');
    eval(sprintf('print -dpng plt/%s-lin.png;',dat.nam));    
    delete(gcf);
    
    %% make log plot
    figland('on');
    % top frame flow
    subplot(3,1,1);
    plot(dat.dn.raw,dat.flow.raw,'ro');
    hold;
    plot(dat.dn.daily,dat.flow.daily,'b.');    
    grid on;
    set(gca,'yscale','log');
    set(gca,'xlim',[min(dn) max(dn)]);
    datetick('keeplimits');
    ylabel('flow m3 s-1');
    title(dat.nam);
    % middle frame conc
    subplot(3,1,2);
    plot(dat.dn.raw,dat.conc.raw,'ro');
    hold;
    plot(dat.dn.daily,dat.conc.daily,'k.');
    grid on;
    set(gca,'xlim',[min(dn) max(dn)]);
    set(gca,'yscale','log');
    datetick('keeplimits');
    ylabel('conc ug/L');
    % bottom frame load
    subplot(3,1,3);
%    plot(dat.dn.raw,dat.load.raw,'ro');
    plot(dat.dn.daily,dat.load.daily,'k.');
    hold;
    grid on;
    set(gca,'xlim',[min(dn) max(dn)]);
    datetick('keeplimits');
    set(gca,'yscale','log');
    ylabel('load lb/yr');
    set(gcf,'paperorientation','portrait');
    eval(sprintf('print -dpng plt/%s-log.png;',dat.nam));    
    delete(gcf);
    
    % save
    eval(sprintf('%s = dat;',dat.nam));
    str = [str ' ' dat.nam];
    clear dat;
end 
eval(str);

% This was regressing flow against nearby rivers.
% The relationships weren't all that strong.
% Because the "only" need was to fill 2001-2003, instead of these
% regressions I decided it was better to use seasonal means from 
% 2004-2010.
% %% get river data
% rivdat = load([q.in.dir q.in.fil]);
% q.dn.raw = rivdat.dn;
% q.flow.all = nan*ones(size(rivdat.m3persec,1),length(dn));
% for i = 1:length(dn)
%     q.flow.all(:,i) = rivdat.m3persec(:,q.dn.raw==dn(i));
% end
% q.nams = rivdat.rivnam;
% clear rivdat;
%   %% for each selected river regress against flow
%     maxr2 = 0;
%     for iriv = 1:length(dat.rivnams)
%         [~,rivind] = ismember(q.nams,dat.rivnams{iriv});
%         riv = q.flow.all(find(rivind),:);
%         ind = find(~isnan(riv) & ~isnan(dat.flow.all));
%         figport('on');
%         subplot(2,1,1);
%         plot(dn(ind),riv(ind),'b.');
%         hold;
%         plot(dn(ind),dat.flow.all(ind),'g.');
%         title(sprintf('b=%s g=%s',dat.rivnams{iriv},dat.nam));
%         datetick;
%         subplot(2,1,2);
%         plot(riv(ind),dat.flow.all(ind),'k.');
%         r2 = corrcoef(riv(ind),dat.flow.all(ind));
%         r2 = r2(1,2).^2;
%         t = get(gca,'title');
%         title([dat.rivnams{iriv} t.String sprintf(' r2 = %f',r2)]);
%         if r2 > maxr2
%             maxr2 = r2;
%             bestind = find(rivind);
%         end
%         xlabel(dat.rivnams{iriv})
%         ylabel(dat.nam);
%         clear ind riv t r2;
%     end

% end of module
diary off;