% SomersetLoadCalc 25-May-2019 

% Compute estimated loads at daily resolution for Somerset
% Save results in a mat file and a plot, using a format uniform 
%      to all 18 sources in the overall analysis.
% Input data: file created from RIDEM spreadsheet by Inventory module.

% notes on methods:

%% Somerset
% No TN available. Used Sum(TKN,NO32), after replacing outliers. Missing 
%   early years filled by mean seasonal cycle of later years. Avg flow 
%   only available during early years; estimated as max flow (available 
%   all years) minus a constant offset determined from the difference 
%   between max flow and avg flow when both measured during early years.

% [[ An earlier version of this module treated Fall River, using data in 
%       the same spreadsheet containing the Somerset data. Here are the
%       corresponding notes. (These are NOT the Fall River data actually 
%       used; they are in a different set of spreadsheets, obtained 
%       directly from FR WWTF.)
%
%% Fall River
% Conc: No TN available. Used Sum(TKN,NO2,NO3), after replacing outliers 
%   with neighboring values. First 2 months of 2000 filled using means of 
%   all later years.
% Flow: No MO AVG available. Used monthly max values (LimType DAILY MX) 
%   minus a constant offset. The offset is alpha*mean(monthly max), where
%   alpha is determined from Somerset data as the ratio of the mean 
%   difference between simultaneously observed max flow and avg flow, and 
%   the mean max flow from observations during all years. 
% ]]



% basic initial setup
wipe;
modprelims;

% retrieve inputs
ingrps = { 'Config'; }; inputsdiary;

%% initial prep
ddn = datenum(2001,1,1):datenum(2017,12,31); % daily dn
% 1 MGD * mg/L = 8.338 lb/d = 3043 lb/y
newrdme = 'ddn = daily datenum; TNload [lb/y]; TNconc [mg/l]; Qflow [MGD]';
pltdir = ['C:\dc\consult\2018nbep\analysis\NutrientLoads\WWTFs\'...
    'MA2\MA2LoadCalc\plt'];
% 1 to force preview of all filloutliers calls; 0 to skip them


%% Somerset
nam = 'Somerset';
fprintf([nam '\n']);

load([Sindir nam]);
readme = newrdme;
% Concentration [mg/l]
TNconc = filloutliers(NO32.Mx + TKN.Mx,'nearest');
% fill early years using seasonal mean of later years
blck = reshape(TNconc,12,17)';
smn = nanmean(blck);
for imon = 1:12
    blck(isnan(blck(:,imon)),imon) = smn(imon);
end
blck = blck';
TNconc = blck(:);
clear smn imon blck;

%   interp from monthly values to daily
TNconc = interp1(dn,TNconc,ddn);
%   fill NaNs in first and last half-month using nearest value
TNconc = fillmissing(TNconc,'nearest');
% Flow [MGD]
Qflow = Q.Av;
Mx = filloutliers(Q.Mx,'nearest'); % remove several notably higher values
Mx = fillmissing(Mx,'linear'); % fill a couple missing dates
offs = nanmean(Mx-Q.Av);
Qflow(isnan(Qflow)) = Mx(isnan(Qflow))-offs;
clear Mx;

% % for fall river below
% offsfrac = offs/nanmean(Q.Mx);
% clear offs;
%   interp from monthly values to daily
Qflow = interp1(dn,Qflow,ddn);
%   fill NaNs in first and last half-month using nearest value
Qflow = fillmissing(Qflow,'nearest');
% Load [lb/y]
TNload = 3043* TNconc.*Qflow;
eval(sprintf('save dat/%s readme TNload TNconc Qflow ddn;',nam));

makeplot(nam,ddn,TNload,TNconc,Qflow);

clear dn NH4 NO2 NO3 NO32 Q TKN TNconc TNload Qflow nam readme;



% %% Fall River
% nam = 'FallRiver';
% fprintf([nam '\n']);
% 
% load([FRindir nam]);
% readme = newrdme;
% % Concentration [mg/l]
% NO3.Av = filloutliers(NO3.Av,'nearest','median','ThresholdFactor',5);
% NO2.Av = filloutliers(NO2.Av,'nearest','median','ThresholdFactor',24);
% TKN.Av = filloutliers(TKN.Av,'nearest','median','ThresholdFactor',24);
% TNconc = NO3.Av + NO2.Av + TKN.Av;
% % fill first two points  using seasonal mean of later years
% blck = reshape(TNconc,12,17)';
% smn = nanmean(blck);
% for imon = 1:12
%     blck(isnan(blck(:,imon)),imon) = smn(imon);
% end
% blck = blck';
% TNconc = blck(:);
% %   interp from monthly values to daily
% TNconc = interp1(dn,TNconc,ddn);
% %   fill NaNs in first and last half-month using nearest value
% TNconc = fillmissing(TNconc,'nearest');
% % Flow [MGD]
% Qflow = Q.Mx;
% % fill first two points  using seasonal mean of later years
% blck = reshape(Qflow,12,17)';
% smn = nanmean(blck);
% for imon = 1:12
%     blck(isnan(blck(:,imon)),imon) = smn(imon);
% end
% blck = blck';
% Qflow = blck(:);
% clear smn imon blck;
% 
% offs = offsfrac*nanmean(Qflow);
% Qflow = Qflow - offs;
% clear offs offsfrac;
% 
% %   interp from monthly values to daily
% Qflow = interp1(dn,Qflow,ddn);
% %   fill NaNs in first and last half-month using nearest value
% Qflow = fillmissing(Qflow,'nearest');
% % Load [lb/y]
% TNload = 3043* TNconc.*Qflow;
% eval(sprintf('save dat/%s readme TNload TNconc Qflow ddn;',nam));
% 
% makeplot(nam,ddn,TNload,TNconc,Qflow);
% 
% clear dn NH4 NO2 NO3 NO32 Q TKN TNconc TNload Qflow nam readme;
% 



% end of module
diary off;